@@ -16,7 +16,7 @@ def rocketmq_handler_wrapper(f):
 
 
 class ConsumerRocketMQ(ConsumerFactory):
-    def __init__(self, consumer_group_name='', lookup_address='', node_address='', access_key='', access_secret='', thread_num=None, batch_size=None, **mq_options):
+    def __init__(self, consumer_group_name='', channel='', lookup_address='', node_address='', access_key='', access_secret='', thread_num=None, batch_size=None, **mq_options):
         self.consumer = PushConsumer(consumer_group_name)
         self.consumer.set_name_server_address(lookup_address)
         if thread_num and thread_num > 0:
@@ -25,7 +25,7 @@ class ConsumerRocketMQ(ConsumerFactory):
             self.consumer.set_message_batch_max_size(batch_size)
         if access_key:
             self.consumer.set_session_credentials(
-                access_key=access_key, access_secret=access_secret)
+                access_key=access_key, access_secret=access_secret, channel=channel)
 
     def Register(self, topic_group: str, topic: str, callback, **route):
         self.consumer.subscribe(
